package com.zhyc.module.biosafety.mapper;

import java.util.List;
import com.zhyc.module.biosafety.domain.Immunity;
import org.apache.ibatis.annotations.Mapper;

/**
 * 免疫Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Mapper
public interface ImmunityMapper 
{
    /**
     * 查询免疫
     * 
     * @param id 免疫主键
     * @return 免疫
     */
    public Immunity selectImmunityById(Long id);

    /**
     * 查询免疫列表
     * 
     * @param immunity 免疫
     * @return 免疫集合
     */
    public List<Immunity> selectImmunityList(Immunity immunity);

    /**
     * 新增免疫
     * 
     * @param immunity 免疫
     * @return 结果
     */
    public int insertImmunity(List<Immunity> immunity);

    /**
     * 修改免疫
     * 
     * @param immunity 免疫
     * @return 结果
     */
    public int updateImmunity(Immunity immunity);

    /**
     * 删除免疫
     * 
     * @param id 免疫主键
     * @return 结果
     */
    public int deleteImmunityById(Long id);

    /**
     * 批量删除免疫
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteImmunityByIds(Long[] ids);
}
